@@ -27,6 +27,13 @@ def one_loop_one_strip():
     return x, y, z
 
 
+@pytest.fixture
+def xyz_chunk_test():
+    x, y = np.meshgrid(np.arange(5), np.arange(5))
+    z = 0.5*np.abs(y - 2) + 0.1*(x - 2)
+    return x, y, z
+
+
 @pytest.mark.parametrize("name", util_test.all_names())
 @pytest.mark.parametrize("zlevel", [-1e-10, 1.0+1e10, np.nan, -np.nan, np.inf, -np.inf])
 def test_level_outside(xy_2x2, name, zlevel):
@@ -88,7 +95,7 @@ def test_loop(xy_3x3, name):
     assert_array_equal(codes[0], [1, 2, 2, 2, 79])
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_simple(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -100,6 +107,8 @@ def test_lines_simple(name, line_type):
     levels = np.arange(-1.0, 1.01, 0.1)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -109,7 +118,7 @@ def test_lines_simple(name, line_type):
     compare_images(image_buffer, "lines_simple.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_simple_chunk(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -117,10 +126,14 @@ def test_lines_simple_chunk(name, line_type):
     from .image_comparison import compare_images
 
     x, y, z = simple((30, 40))
-    cont_gen = contour_generator(x, y, z, name=name, line_type=line_type, chunk_size=2)
+    cont_gen = contour_generator(
+        x, y, z, name=name, line_type=line_type, chunk_size=2, thread_count=1,
+    )
     levels = np.arange(-1.0, 1.01, 0.1)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -130,7 +143,34 @@ def test_lines_simple_chunk(name, line_type):
     compare_images(image_buffer, "lines_simple_chunk.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
+@pytest.mark.threads
+@pytest.mark.parametrize("line_type", LineType.__members__.values())
+@pytest.mark.parametrize("thread_count", util_test.thread_counts())
+def test_lines_simple_chunk_threads(line_type, thread_count):
+    from contourpy.util.mpl_renderer import MplTestRenderer
+
+    from .image_comparison import compare_images
+
+    x, y, z = simple((30, 40))
+    cont_gen = contour_generator(
+        x, y, z, name="threaded", line_type=line_type, chunk_size=2, thread_count=thread_count,
+    )
+    levels = np.arange(-1.0, 1.01, 0.1)
+
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == thread_count
+
+    renderer = MplTestRenderer()
+    for i in range(len(levels)):
+        renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
+    image_buffer = renderer.save_to_buffer()
+
+    compare_images(image_buffer, "lines_simple_chunk.png", f"{line_type}_{thread_count}")
+
+
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_simple_no_corner_mask(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -142,6 +182,8 @@ def test_lines_simple_no_corner_mask(name, line_type):
     levels = np.arange(-1.0, 1.01, 0.1)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -151,7 +193,7 @@ def test_lines_simple_no_corner_mask(name, line_type):
     compare_images(image_buffer, "lines_simple_no_corner_mask.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_simple_no_corner_mask_chunk(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -160,10 +202,13 @@ def test_lines_simple_no_corner_mask_chunk(name, line_type):
 
     x, y, z = simple((30, 40), want_mask=True)
     cont_gen = contour_generator(
-        x, y, z, name=name, line_type=line_type, corner_mask=False, chunk_size=2)
+        x, y, z, name=name, line_type=line_type, corner_mask=False, chunk_size=2, thread_count=1,
+    )
     levels = np.arange(-1.0, 1.01, 0.1)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -173,7 +218,37 @@ def test_lines_simple_no_corner_mask_chunk(name, line_type):
     compare_images(image_buffer, "lines_simple_no_corner_mask_chunk.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
+@pytest.mark.threads
+@pytest.mark.parametrize("line_type", LineType.__members__.values())
+@pytest.mark.parametrize("thread_count", util_test.thread_counts())
+def test_lines_simple_no_corner_mask_chunk_threads(line_type, thread_count):
+    from contourpy.util.mpl_renderer import MplTestRenderer
+
+    from .image_comparison import compare_images
+
+    x, y, z = simple((30, 40), want_mask=True)
+    cont_gen = contour_generator(
+        x, y, z, name="threaded", line_type=line_type, corner_mask=False, chunk_size=2,
+        thread_count=thread_count,
+    )
+    levels = np.arange(-1.0, 1.01, 0.1)
+
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == thread_count
+
+    renderer = MplTestRenderer()
+    for i in range(len(levels)):
+        renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
+    image_buffer = renderer.save_to_buffer()
+
+    compare_images(
+        image_buffer, "lines_simple_no_corner_mask_chunk.png", f"{line_type}_{thread_count}",
+    )
+
+
+@pytest.mark.image
 @pytest.mark.parametrize("name", util_test.corner_mask_names())
 def test_lines_simple_corner_mask(name):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -186,6 +261,8 @@ def test_lines_simple_corner_mask(name):
     levels = np.arange(-1.0, 1.01, 0.1)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -195,7 +272,7 @@ def test_lines_simple_corner_mask(name):
     compare_images(image_buffer, "lines_simple_corner_mask.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name", util_test.corner_mask_names())
 def test_lines_simple_corner_mask_chunk(name):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -205,10 +282,13 @@ def test_lines_simple_corner_mask_chunk(name):
     x, y, z = simple((30, 40), want_mask=True)
     line_type = LineType.SeparateCode
     cont_gen = contour_generator(
-        x, y, z, name=name, line_type=line_type, corner_mask=True, chunk_size=2)
+        x, y, z, name=name, line_type=line_type, corner_mask=True, chunk_size=2, thread_count=1,
+    )
     levels = np.arange(-1.0, 1.01, 0.1)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -218,7 +298,37 @@ def test_lines_simple_corner_mask_chunk(name):
     compare_images(image_buffer, "lines_simple_corner_mask_chunk.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
+@pytest.mark.threads
+@pytest.mark.parametrize("line_type", LineType.__members__.values())
+@pytest.mark.parametrize("thread_count", util_test.thread_counts())
+def test_lines_simple_corner_mask_chunk_threads(line_type, thread_count):
+    from contourpy.util.mpl_renderer import MplTestRenderer
+
+    from .image_comparison import compare_images
+
+    x, y, z = simple((30, 40), want_mask=True)
+    cont_gen = contour_generator(
+        x, y, z, name="threaded", line_type=line_type, corner_mask=True, chunk_size=2,
+        thread_count=thread_count,
+    )
+    levels = np.arange(-1.0, 1.01, 0.1)
+
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == thread_count
+
+    renderer = MplTestRenderer()
+    for i in range(len(levels)):
+        renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
+    image_buffer = renderer.save_to_buffer()
+
+    compare_images(
+        image_buffer, "lines_simple_corner_mask_chunk.png", f"{line_type}_{thread_count}",
+    )
+
+
+@pytest.mark.image
 @pytest.mark.parametrize("name", util_test.quad_as_tri_names())
 def test_lines_simple_quad_as_tri(name):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -229,6 +339,10 @@ def test_lines_simple_quad_as_tri(name):
     cont_gen = contour_generator(x, y, z, name=name, quad_as_tri=True)
     levels = np.arange(-1.0, 1.01, 0.1)
 
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
+    assert cont_gen.quad_as_tri
+
     line_type = cont_gen.line_type
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -238,7 +352,7 @@ def test_lines_simple_quad_as_tri(name):
     compare_images(image_buffer, "lines_simple_quad_as_tri.png", f"{name}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_random(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -250,6 +364,8 @@ def test_lines_random(name, line_type):
     levels = np.arange(0.0, 1.01, 0.2)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -259,7 +375,7 @@ def test_lines_random(name, line_type):
     compare_images(image_buffer, "lines_random.png", f"{name}_{line_type}", max_threshold=103)
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_random_chunk(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -267,10 +383,14 @@ def test_lines_random_chunk(name, line_type):
     from .image_comparison import compare_images
 
     x, y, z = random((30, 40), mask_fraction=0.0)
-    cont_gen = contour_generator(x, y, z, name=name, line_type=line_type, chunk_size=2)
+    cont_gen = contour_generator(
+        x, y, z, name=name, line_type=line_type, chunk_size=2, thread_count=1,
+    )
     levels = np.arange(0.0, 1.01, 0.2)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -289,7 +409,36 @@ def test_lines_random_chunk(name, line_type):
     )
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
+@pytest.mark.threads
+@pytest.mark.parametrize("line_type", LineType.__members__.values())
+@pytest.mark.parametrize("thread_count", util_test.thread_counts())
+def test_lines_random_chunk_threads(line_type, thread_count):
+    from contourpy.util.mpl_renderer import MplTestRenderer
+
+    from .image_comparison import compare_images
+
+    x, y, z = random((30, 40), mask_fraction=0.0)
+    cont_gen = contour_generator(
+        x, y, z, name="threaded", line_type=line_type, chunk_size=2, thread_count=thread_count,
+    )
+    levels = np.arange(0.0, 1.01, 0.2)
+
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == thread_count
+
+    renderer = MplTestRenderer()
+    for i in range(len(levels)):
+        renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
+    image_buffer = renderer.save_to_buffer()
+
+    compare_images(
+        image_buffer, "lines_random_chunk.png", f"{line_type}_{thread_count}",
+    )
+
+
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_random_no_corner_mask(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -301,6 +450,8 @@ def test_lines_random_no_corner_mask(name, line_type):
     levels = np.arange(0.0, 1.01, 0.2)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
 
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -310,7 +461,7 @@ def test_lines_random_no_corner_mask(name, line_type):
     compare_images(image_buffer, "lines_random_no_corner_mask.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 def test_lines_random_no_corner_mask_chunk(name, line_type):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -322,9 +473,14 @@ def test_lines_random_no_corner_mask_chunk(name, line_type):
 
     x, y, z = random((30, 40), mask_fraction=0.05)
     cont_gen = contour_generator(
-        x, y, z, name=name, line_type=line_type, corner_mask=False, chunk_size=2)
+        x, y, z, name=name, line_type=line_type, corner_mask=False, chunk_size=2, thread_count=1,
+    )
     levels = np.arange(0.0, 1.01, 0.2)
 
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == 1
+
     renderer = MplTestRenderer()
     for i in range(len(levels)):
         renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
@@ -333,7 +489,37 @@ def test_lines_random_no_corner_mask_chunk(name, line_type):
     compare_images(image_buffer, "lines_random_no_corner_mask_chunk.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
+@pytest.mark.threads
+@pytest.mark.parametrize("line_type", LineType.__members__.values())
+@pytest.mark.parametrize("thread_count", util_test.thread_counts())
+def test_lines_random_no_corner_mask_chunk_threads(line_type, thread_count):
+    from contourpy.util.mpl_renderer import MplTestRenderer
+
+    from .image_comparison import compare_images
+
+    x, y, z = random((30, 40), mask_fraction=0.05)
+    cont_gen = contour_generator(
+        x, y, z, name="threaded", line_type=line_type, corner_mask=False, chunk_size=2,
+        thread_count=thread_count,
+    )
+    levels = np.arange(0.0, 1.01, 0.2)
+
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == thread_count
+
+    renderer = MplTestRenderer()
+    for i in range(len(levels)):
+        renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
+    image_buffer = renderer.save_to_buffer()
+
+    compare_images(
+        image_buffer, "lines_random_no_corner_mask_chunk.png", f"{line_type}_{thread_count}",
+    )
+
+
+@pytest.mark.image
 @pytest.mark.parametrize("name", util_test.corner_mask_names())
 def test_lines_random_corner_mask(name):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -345,6 +531,10 @@ def test_lines_random_corner_mask(name):
     cont_gen = contour_generator(x, y, z, name=name, corner_mask=True, line_type=line_type)
     levels = np.arange(0.0, 1.01, 0.2)
 
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
+
     renderer = MplTestRenderer()
     for i in range(len(levels)):
         renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
@@ -353,7 +543,7 @@ def test_lines_random_corner_mask(name):
     compare_images(image_buffer, "lines_random_corner_mask.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
 @pytest.mark.parametrize("name", util_test.corner_mask_names())
 def test_lines_random_corner_mask_chunk(name):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -362,9 +552,15 @@ def test_lines_random_corner_mask_chunk(name):
 
     x, y, z = random((30, 40), mask_fraction=0.05)
     line_type = LineType.SeparateCode
-    cont_gen = contour_generator(x, y, z, name=name, corner_mask=True, line_type=line_type)
+    cont_gen = contour_generator(
+        x, y, z, name=name, corner_mask=True, line_type=line_type, chunk_size=2, thread_count=1,
+    )
     levels = np.arange(0.0, 1.01, 0.2)
 
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == 1
+
     renderer = MplTestRenderer()
     for i in range(len(levels)):
         renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
@@ -373,7 +569,37 @@ def test_lines_random_corner_mask_chunk(name):
     compare_images(image_buffer, "lines_random_corner_mask_chunk.png", f"{name}_{line_type}")
 
 
-@pytest.mark.needs_mpl
+@pytest.mark.image
+@pytest.mark.threads
+@pytest.mark.parametrize("line_type", LineType.__members__.values())
+@pytest.mark.parametrize("thread_count", util_test.thread_counts())
+def test_lines_random_corner_mask_chunk_threads(line_type, thread_count):
+    from contourpy.util.mpl_renderer import MplTestRenderer
+
+    from .image_comparison import compare_images
+
+    x, y, z = random((30, 40), mask_fraction=0.05)
+    cont_gen = contour_generator(
+        x, y, z, name="threaded", corner_mask=True, line_type=line_type, chunk_size=2,
+        thread_count=thread_count,
+    )
+    levels = np.arange(0.0, 1.01, 0.2)
+
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (15, 20)
+    assert cont_gen.thread_count == thread_count
+
+    renderer = MplTestRenderer()
+    for i in range(len(levels)):
+        renderer.lines(cont_gen.lines(levels[i]), line_type, color=f"C{i}")
+    image_buffer = renderer.save_to_buffer()
+
+    compare_images(
+        image_buffer, "lines_random_corner_mask_chunk.png", f"{line_type}_{thread_count}",
+    )
+
+
+@pytest.mark.image
 @pytest.mark.parametrize("name", util_test.quad_as_tri_names())
 def test_lines_random_quad_as_tri(name):
     from contourpy.util.mpl_renderer import MplTestRenderer
@@ -384,6 +610,10 @@ def test_lines_random_quad_as_tri(name):
     cont_gen = contour_generator(x, y, z, name=name, quad_as_tri=True)
     levels = np.arange(0.0, 1.01, 0.2)
 
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
+    assert cont_gen.quad_as_tri
+
     line_type = cont_gen.line_type
     renderer = MplTestRenderer()
     for i in range(len(levels)):
@@ -394,11 +624,15 @@ def test_lines_random_quad_as_tri(name):
 
 
 @pytest.mark.parametrize("line_type", LineType.__members__.values())
-@pytest.mark.parametrize("name", ["serial"])
+@pytest.mark.parametrize("name", ["serial", "threaded"])
 def test_return_by_line_type(one_loop_one_strip, name, line_type):
     x, y, z = one_loop_one_strip
     cont_gen = contour_generator(x, y, z, name=name, line_type=line_type)
+
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
+
     lines = cont_gen.lines(2.0)
 
     util_test.assert_lines(lines, line_type)
@@ -427,6 +661,62 @@ def test_return_by_line_type(one_loop_one_strip, name, line_type):
         assert_array_equal(offsets, [0, 5, 7])
 
 
+@pytest.mark.threads
+@pytest.mark.parametrize("line_type", LineType.__members__.values())
+@pytest.mark.parametrize("name, thread_count",
+                         [("serial", 1), ("threaded", 1), ("threaded", 2)])
+def test_return_by_line_type_chunk(xyz_chunk_test, name, thread_count, line_type):
+    x, y, z = xyz_chunk_test
+    cont_gen = contour_generator(
+        x, y, z, name=name, line_type=line_type, chunk_count=2, thread_count=thread_count,
+    )
+
+    assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (2, 2)
+    assert cont_gen.chunk_size == (2, 2)
+    assert cont_gen.thread_count == thread_count
+
+    lines = cont_gen.lines(0.45)
+
+    util_test.assert_lines(lines, line_type)
+
+    # Expected points by chunk.
+    expected = (
+        [[2.0, 1.1], [1.5, 1.0], [1.0, 0.9], [0.0, 0.7]],
+        [[4.0, 1.5], [3.0, 1.3], [2.0, 1.1]],
+        [[0.0, 3.3], [1.0, 3.1], [1.5, 3.0], [2.0, 2.9]],
+        [[2.0, 2.9], [3.0, 2.7], [4.0, 2.5]],
+    )
+
+    if line_type == LineType.Separate:
+        assert len(lines) == 4
+        if name == "threaded" and cont_gen.thread_count > 1:
+            # Lines may be in any order so sort lines and expected.
+            lines = util_test.sort_by_first_xy(lines)
+            expected = util_test.sort_by_first_xy(expected)
+        for chunk in range(4):
+            assert_allclose(lines[chunk], expected[chunk])
+    elif line_type == LineType.SeparateCode:
+        assert len(lines[0]) == 4
+        if name == "threaded" and cont_gen.thread_count > 1:
+            # Lines may be in any order so sort lines and expected.
+            lines = util_test.sort_by_first_xy(lines[0], lines[1])
+            expected = util_test.sort_by_first_xy(expected)
+        for chunk in range(4):
+            assert_allclose(lines[0][chunk], expected[chunk])
+            assert_array_equal(lines[1][chunk], [1] + [2]*(len(expected[chunk])-1))
+    elif line_type == LineType.ChunkCombinedCode:
+        assert len(lines[0]) == 4
+        for chunk in range(4):
+            assert_allclose(lines[0][chunk], expected[chunk])
+            assert_array_equal(lines[1][chunk], [1] + [2]*(len(expected[chunk])-1))
+    elif line_type == LineType.ChunkCombinedOffset:
+        assert len(lines[0]) == 4
+        for chunk in range(4):
+            assert_allclose(lines[0][chunk], expected[chunk])
+            assert_array_equal(lines[1][chunk], [0, len(expected[chunk])])
+
+
 @pytest.mark.parametrize("name, line_type", util_test.all_names_and_line_types())
 @pytest.mark.parametrize("corner_mask", [None, False, True])
 def test_lines_random_big(name, line_type, corner_mask):
@@ -438,6 +728,8 @@ def test_lines_random_big(name, line_type, corner_mask):
     levels = np.arange(0.0, 1.01, 0.1)
 
     assert cont_gen.line_type == line_type
+    assert cont_gen.chunk_count == (1, 1)
+    assert cont_gen.thread_count == 1
 
     for level in levels:
         lines = cont_gen.lines(level)
